<?php

namespace Drupal\cdn\Plugin\Validation\Constraint;

use Drupal\Core\StringTranslation\TranslatableMarkup;
use Drupal\Core\Validation\Attribute\Constraint;
use Symfony\Component\Validator\Constraint as SymfonyConstraint;

/**
 * @internal
 *
 * An authority as defined in RFC3986. An authority consists of host, optional
 * userinfo and optional port. The host can be an IP address or registered
 * domain name.
 * @see https://tools.ietf.org/html/rfc3986#section-3.2
 */
#[Constraint(
  id: 'CdnDomain',
  label: new TranslatableMarkup('CDN domain', [], ['context' => 'Validation'])
)]
final class CdnDomainConstraint extends SymfonyConstraint {

  public $message = 'The provided domain %domain is not valid. Provide a hostname like <samp>cdn.com</samp> or <samp>cdn.example.com</samp>. IP addresses and ports are also allowed.';

}
