<?php

declare(strict_types=1);

namespace Drupal\cdn\Plugin\Validation\Constraint;

use Drupal\cdn\CdnSettings;
use Drupal\Core\Config\ConfigValueException;
use Symfony\Component\Validator\Constraint;
use Symfony\Component\Validator\ConstraintValidator;
use Symfony\Component\Validator\Exception\UnexpectedTypeException;

/**
 * @internal
 */
final class CdnEnabledIffDomainConstraintValidator extends ConstraintValidator {

  /**
   * {@inheritdoc}
   *
   * @throws \Symfony\Component\Validator\Exception\UnexpectedTypeException
   *   Thrown when the given constraint is not supported by this validator.
   */
  public function validate($status, Constraint $constraint) {
    if (!$constraint instanceof CdnEnabledIffDomainConstraint) {
      throw new UnexpectedTypeException($constraint, __NAMESPACE__ . '\CdnEnabledIffDomainConstraint');
    }

    // If `cdn.settings:status` is not TRUE, there's nothing to validate.
    if (!$status) {
      return;
    }

    // Retrieve `cdn.settings:mapping`. There must be >=1 configured domain.
    // @see \Drupal\cdn\CdnSettings::getDomains()
    $mapping = $this->context->getRoot()->get('mapping')->getValue();
    try {
      $flattened = iterator_to_array(new \RecursiveIteratorIterator(new \RecursiveArrayIterator(CdnSettings::buildLookupTable($mapping))), FALSE);
    }
    catch (ConfigValueException) {
      // This indicates an invalid `cdn.settings:mapping` value.
      return;
    }
    $configured_domains = array_filter($flattened);
    if (empty($configured_domains)) {
      $this->context->addViolation($constraint->message);
    }
  }

}
